import { createContext, useContext } from "react";
export const MultichainConnectContext = createContext({
    address: null,
    setAddress: (_) => {
        throw new Error("Missing <MultichainConnectContext /> parent element");
    },
    error: null,
    isConnected: false,
    setIsConnected: (_) => {
        throw new Error("Missing <MultichainConnectContext /> parent element");
    },
    isLoading: false,
    setIsLoading: (_) => {
        throw new Error("Missing <MultichainConnectContext /> parent element");
    },
    signer: null,
    setSigner: (_) => {
        throw new Error("Missing <MultichainConnectContext /> parent element");
    },
    connector: null,
    setConnector: (_) => {
        throw new Error("Missing <MultichainConnectContext /> parent element");
    },
    connectors: null,
});
export const useConnect = () => {
    const { signer, setSigner, connector, connectors, setConnector, setIsLoading, isConnected, setIsConnected, address, setAddress, } = useContext(MultichainConnectContext);
    const connect = async (newConnector) => {
        if (signer) {
            return;
        }
        if (connector) {
            return;
        }
        setIsLoading(true);
        const onAccountsChanged = async (accounts) => {
            setAddress(accounts[0]);
            const newSigner = await newConnector.createSessionSigner(accounts[0]);
            setSigner(newSigner);
        };
        await newConnector.enable({ onAccountsChanged });
        setConnector(connector);
        setIsLoading(false);
        setIsConnected(true);
    };
    return { connect, isConnected, connectors, address };
};
export const useDisconnect = () => {
    const { isConnected, setIsConnected, connector, setConnector, setSigner } = useContext(MultichainConnectContext);
    const disconnect = () => {
        if (!isConnected) {
            return;
        }
        if (connector) {
            connector.disable();
            setConnector(null);
        }
        setSigner(null);
        setIsConnected(false);
    };
    return { disconnect };
};
export const useSigner = () => {
    const { signer } = useContext(MultichainConnectContext);
    return { signer };
};
