import { useState, useEffect, useCallback } from "react";
import { ethers } from "ethers";
export function useSigner() {
    const [loading, setLoading] = useState(true);
    const [provider, setProvider] = useState(null);
    const [signer, setSigner] = useState(null);
    const [address, setAddress] = useState(null);
    const connect = useCallback(async () => {
        if (loading) {
            return Promise.reject(new Error("connect() called too soon - wait for loading to be false!"));
        }
        else if (provider === null) {
            return Promise.reject(new Error("No window.ethereum provider found. Install MetaMask if you haven't!"));
        }
        return provider.send("eth_requestAccounts", []);
    }, [loading, provider]);
    useEffect(() => {
        if (window.ethereum === undefined) {
            console.error("Could not find injected wallet provider");
            setLoading(false);
            return;
        }
        const provider = new ethers.providers.Web3Provider(window.ethereum);
        function handleAccountsChanged(accounts) {
            if (accounts.length > 0) {
                const address = accounts[0].toLowerCase();
                const signer = provider.getSigner(address);
                setAddress(address);
                setSigner(signer);
            }
            else {
                setAddress(null);
                setSigner(null);
            }
        }
        window.ethereum.on("accountsChanged", handleAccountsChanged);
        provider.send("eth_accounts", []).then((accounts) => {
            setLoading(false);
            setProvider(provider);
            console.log("we set the provider", provider);
            if (accounts.length > 0) {
                const address = accounts[0].toLowerCase();
                const signer = provider.getSigner(address);
                setAddress(address);
                setSigner(signer);
            }
        });
        return () => {
            window.ethereum.removeListener("accountsChanged", handleAccountsChanged);
        };
    }, []);
    return { loading, connect, signer, provider, address };
}
