export const getCanvasSessionKey = (address) => `CANVAS_SESSION:${address}`;
function normalize(strArray) {
    const resultArray = [];
    if (strArray.length === 0) {
        return "";
    }
    if (typeof strArray[0] !== "string") {
        throw new TypeError("Url must be a string. Received " + strArray[0]);
    }
    if (strArray[0].match(/^[^/:]+:\/*$/) && strArray.length > 1) {
        strArray[0] = strArray.shift() + strArray[0];
    }
    if (strArray[0].match(/^file:\/\/\//)) {
        strArray[0] = strArray[0].replace(/^([^/:]+):\/*/, "$1:///");
    }
    else {
        strArray[0] = strArray[0].replace(/^([^/:]+):\/*/, "$1://");
    }
    for (let i = 0; i < strArray.length; i++) {
        let component = strArray[i];
        if (typeof component !== "string") {
            throw new TypeError("Url must be a string. Received " + component);
        }
        if (component === "") {
            continue;
        }
        if (i > 0) {
            component = component.replace(/^[\/]+/, "");
        }
        if (i < strArray.length - 1) {
            component = component.replace(/[\/]+$/, "");
        }
        else {
            component = component.replace(/[\/]+$/, "/");
        }
        resultArray.push(component);
    }
    let str = resultArray.join("/");
    str = str.replace(/\/(\?|&|#[^!])/g, "$1");
    const parts = str.split("?");
    str = parts.shift() + (parts.length > 0 ? "?" : "") + parts.join("&");
    return str;
}
export function urlJoin(...args) {
    const parts = Array.from(Array.isArray(args[0]) ? args[0] : args);
    return normalize(parts);
}
export function compareObjects(a, b) {
    for (const key in a) {
        if (a[key] !== b[key]) {
            return false;
        }
    }
    for (const key in b) {
        if (b[key] !== a[key]) {
            return false;
        }
    }
    return true;
}
export async function getRecentBlock(host, chain, chainId) {
    const res = await fetch(urlJoin(host, "latest_block", chain, chainId.toString()), { method: "GET" });
    const block = await res.json();
    return { ...block, chainId };
}
